# Handler for OpenNebula DatastorePool
#
# @author Michal Kimle
class Nifty::Backends::Utils::Opennebula::DatastoreHandler < Nifty::Backends::Utils::Opennebula::Handler

  # Constructor
  #
  # @see Nifty::Backends::Utils::Opennebula::Handler#initialize
  def initialize(client)
    super(client)
    @pool = OpenNebula::DatastorePool.new(client)
  end

  # Returns list of datastores matching the names
  # If there is no datastore with given name, it's skipped.
  #
  # @param [Array] names array of the names
  # @return [Array] array of found datastores
  def datastores(names)
    reload!

    datastores = []
    names.each do |name|
      datastore = pool.find { |ds| ds.name == name }

      unless datastore
        logger.warn("Datastore #{name.inspect} was not found, skipping.")
        next
      end

      datastores << datastore
    end

    datastores
  end
end
