# Converts appliances into events
#
# @author Michal Kimle
class Nifty::Event::Converter
  # Converts appliance into event
  #
  # @param [Cloud::Appliance::Descriptor::Appliance] appliance
  # @param [Nifty::Backend] backend
  # @param [Nifty::TransferMethod] transfer_method
  # @param [Hash] parameters
  # @raise [Nifty::Errors::Event::ConverterError] when something goes wrong while conversion
  # @return [Nifty::Event] description of returned object
  def self.convert_appliance(appliance, backend, transfer_method, parameters)
    events_module = "Nifty::Events::#{backend.name.demodulize}".constantize

    logger.debug "Converting appliance #{appliance.inspect}"
    event_type = "#{appliance.action}_event".camelize

    fail Nifty::Errors::Event::ConverterError, "No such event type for action #{appliance.action.inspect}" unless events_module.constants.include?(event_type.to_sym)
    event_class = events_module.const_get(event_type)

    fail Nifty::Errors::Event::ConverterError, "Class #{event_class.inspect} doesn't represent an event" unless (event_class.respond_to?('event?') && event_class.event? && event_class.public_instance_methods.include?(:run))

    event = backend.create_event(event_class, appliance, transfer_method, parameters)
    logger.debug "Converted event: #{event.inspect}"

    event
  end
end
