# Abstract class for all events
#
# @author Michal Kimle
# @abstract
# @attr_reader [Cloud::Appliance::Descriptor::Appliance] appliance appliance representing an event
# @attr_reader [Nifty::TransferMethod] transfer_method event's transfer method
class Nifty::Events::Event
  attr_reader :appliance, :transfer_method

  # Constructor
  # @abstract
  # @param [Cloud::Appliance::Descriptor::Appliance] appliance appliance representing an event
  # @param [Nifty::TransferMethod] transfer_method event's transfer method
  def initialize(appliance, transfer_method)
    appliance.os = Cloud::Appliance::Descriptor::Os.new unless appliance.os
    @appliance = appliance
    @transfer_method = transfer_method
  end

  # Helper method to recognize NIFTY event
  #
  # @return [TrueClass,FalseClass] whether class is an event or not
  def self.event?
    false
  end

  # Runs the event
  #
  # @raise Nifty::Errors::Events::EventError
  def run
  end
end
