# Copy transfer method
# Copies file to the destination and clens it after the event is processed
class Nifty::TransferMethods::Opennebula::Cp < Nifty::TransferMethod
  class << self
    # @see Nifty::TransferMethod#transfer_method?
    def transfer_method?
      true
    end

    # @see Nifty::TransferMethod#description
    def description
      'Copy transfer method - copies images localy within one host'
    end

    # @see Nifty::TransferMethod#backend
    def backend
      Nifty::Backends::Opennebula
    end
  end

  # @see Nifty::TransferMethod#initialize
  def initialize(destination, options={})
    fail Nifty::Errors::TransferMethods::DestinationNotDirectoryError, "Destination #{destination.inspect} is not a directory" unless (destination && File.directory?(destination))
    fail Nifty::Errors::TransferMethods::DestinationNotWritableError, "Destination directory #{destination.inspect} is not writable" unless File.writable?(destination)

    super(destination)
  end

  # @see Nifty::TransferMethod#transfer
  def transfer(file)
    super(file)

    logger.debug("Copying file #{file.inspect} to destination #{destination.inspect}")
    FileUtils.cp file, destination
    destination_file file
  end

  # @see Nifty::TransferMethod#clean_copy
  def clean_copy(file)
    df = destination_file file
    logger.debug("Deleting files #{df.inspect}")
    FileUtils.rm df
  rescue SystemCallError => ex
    logger.warn("Cannot delete file #{df.inspect}, #{ex.message}")
  end

  private

  def destination_file(file)
    File.join(destination, File.basename(file))
  end
end
