require 'etc'
require 'mixlib/shellout'

# SCP transfer method
# Copies file from remote server to the destination and clens it after the event is processed
class Nifty::TransferMethods::Opennebula::Scp < Nifty::TransferMethod
  attr_reader :user, :host
  class << self
    # @see Nifty::TransferMethod#description
    def description
      'SCP transfer method - copies images from remote host'
    end

    # @see Nifty::TransferMethod#backend
    def backend
      Nifty::Backends::Opennebula
    end

    # @see Nifty::TransferMethod#transfer_method?
    def transfer_method?
      true
    end
  end

  # @see Nifty::TransferMethod#initialize
  def initialize(destination, options={})
    fail Nifty::Errors::TransferMethods::NoRemoteHostError, 'Missing remote host option for SCP transfer method' unless options[:'remote-host']

    @host = options[:'remote-host']
    @user = options[:'remote-user'] || Etc.getlogin

    super(destination, options)
  end

  # @see Nifty::TransferMethod#transfer
  def transfer(file)
    destination_line = "#{user}@#{host}:#{destination}"
    logger.debug("Copying file #{file.inspect} to destination #{destination_line.inspect}")
    scp_command = Mixlib::ShellOut.new('scp', file, destination_line)
    scp_command.run_command

    if scp_command.error?
      raise Nifty::Errors::TransferMethods::ScpCommandExecutionError, "Command #{scp_command.command.inspect} terminated with an " \
                                                                      "error: #{scp_command.stderr}"
    end

    destination_file file
  end

  # @see Nifty::TransferMethod#clean_copy
  def clean_copy(file)
    # no remote cleaning
  end

  private

  #TODO duplicit method (cp transfer method) -> move to helper class
  def destination_file(file)
    File.join(destination, File.basename(file))
  end
end
